humbletray
==========

.. contents:: **Table of Contents**
    :backlinks: none

Installation
------------

humbletray is distributed on `PyPI <https://pypi.org>`_ as a universal
wheel and is a WIP.

These are helper methods to install justpy as a systray app as a python-all-the-way alternative to Electron.

Also a basic Quasar wrapping layout and the ability to launch as a chrome app if installed.

.. code-block:: bash

    $ pip install humbletray

License
-------

humbletray is distributed under the terms of both

- `MIT License <https://choosealicense.com/licenses/mit>`_
- `Apache License, Version 2.0 <https://choosealicense.com/licenses/apache-2.0>`_

at your option.
